@@ -1,19 +1,19 @@
 # coding: utf-8
+from __future__ import unicode_literals
 import re
 
 from django.db import models
 from django.core.exceptions import ValidationError
+import six
 
-from pyuploadcare.dj import forms, UploadCare
-from pyuploadcare.exceptions import InvalidRequestError
-from pyuploadcare.file import File, FileGroup
+from . import forms
+from ..exceptions import InvalidRequestError
+from ..api_resources import File, FileGroup
 
 
-class FileField(models.Field):
-
-    __metaclass__ = models.SubfieldBase
-
-    description = "UploadCare file id/URI with cached data"
+class FileField(six.with_metaclass(models.SubfieldBase), models.Field):
+    """Django model field that stores uploaded file as Uploadcare CDN url.
+    """
 
     def get_internal_type(self):
         return "TextField"
@@ -25,23 +25,23 @@ class FileField(models.Field):
         if isinstance(value, File):
             return value
 
-        if not isinstance(value, basestring):
+        if not isinstance(value, six.string_types):
             raise ValidationError(
-                u'Invalid value for a field: string was expected'
+                'Invalid value for a field: string was expected'
             )
 
         try:
-            return UploadCare().file(value)
+            return File(value)
         except InvalidRequestError as exc:
             raise ValidationError(
-                u'Invalid value for a field: {exc}'.format(exc=exc)
+                'Invalid value for a field: {exc}'.format(exc=exc)
             )
 
     def get_prep_value(self, value):
         if value is None or value == '':
             return value
         else:
-            return value.serialize()
+            return value.cdn_url
 
     def get_db_prep_save(self, value, connection=None):
         if value:
@@ -58,7 +58,7 @@ class FileField(models.Field):
         return models.Field.formfield(self, **kwargs)
 
 
-pattern_of_crop = re.compile(u'''
+pattern_of_crop = re.compile('''
     ^
     (
         disabled| # "disabled"
@@ -72,10 +72,25 @@ pattern_of_crop = re.compile(u'''
 
 
 class ImageField(FileField):
+    """Django model field that stores uploaded image as Uploadcare CDN url.
+
+    It supports manual crop as well. *manual_crop* can be set to one
+    of the following values:
+
+    - ``None``, ``"disabled"`` — crop disabled;
+    - ``""`` — crop is enabled and the user will be able to select any area
+      on an image;
+    - ``"2:3"`` — user will be able to select an area with aspect ratio *2:3*;
+    - ``"200x300"`` — same as previous, but if the selected area is bigger
+      than *200x300*, it will be scaled down to these dimensions;
+    - ``"200x300 upscale"`` — same as previous, but the selected area
+      will be scaled even if it is smaller than the specified size.
+
+    """
 
     def __init__(self, manual_crop=None, *args, **kwargs):
         is_crop_valid = (
-            isinstance(manual_crop, basestring) and
+            isinstance(manual_crop, six.string_types) and
             pattern_of_crop.match(manual_crop)
         )
         if not (manual_crop is None or is_crop_valid):
@@ -91,9 +106,12 @@ class ImageField(FileField):
         return models.Field.formfield(self, **kwargs)
 
 
-class FileGroupField(models.Field):
+class FileGroupField(six.with_metaclass(models.SubfieldBase), models.Field):
+    """Django model field that stores uploaded file group as Uploadcare CDN url.
 
-    __metaclass__ = models.SubfieldBase
+    It provides multiple file uploading.
+
+    """
 
     def get_internal_type(self):
         return "TextField"
@@ -105,23 +123,23 @@ class FileGroupField(models.Field):
         if isinstance(value, FileGroup):
             return value
 
-        if not isinstance(value, basestring):
+        if not isinstance(value, six.string_types):
             raise ValidationError(
-                u'Invalid value for a field: string was expected'
+                'Invalid value for a field: string was expected'
             )
 
         try:
-            return UploadCare().file_group(value)
+            return FileGroup(value)
         except InvalidRequestError as exc:
             raise ValidationError(
-                u'Invalid value for a field: {exc}'.format(exc=exc)
+                'Invalid value for a field: {exc}'.format(exc=exc)
             )
 
     def get_prep_value(self, value):
         if value is None or value == '':
             return value
         else:
-            return value.id
+            return value.cdn_url
 
     def get_db_prep_save(self, value, connection=None):
         if value:
@@ -139,6 +157,11 @@ class FileGroupField(models.Field):
 
 
 class ImageGroupField(FileGroupField):
+    """Django model field that stores uploaded image group as Uploadcare CDN url.
+
+    It provides multiple image uploading.
+
+    """
 
     def formfield(self, **kwargs):
         kwargs['form_class'] = forms.ImageGroupField
